#!/bin/bash
##################################################################
# 0 or 1 or 2 arguments :
#   - 1st = suffix of the model name (eg : foo --> model = lmdz1d_foo.e)
#   - 2nd = suffix of the simulation name (eg : 4 --> output file = histmth_foo_4.nc)
# If there is no model name suffix, 1st argument should be a dot.
# Examples :
#   xqt.x norad 3 --> model = lmdz1d_norad.e
#                     output = histmth_norad_3.nc
#   xqt.x . 22 --> model = lmdz1d.e
#                  output = histmth_22.nc
##################################################################
#
if [ -n "$1" -a "$1" != \. ]
then
 exec="_$1"
else
 exec=""
fi
if [ -n "$2" -a "$2" != \. ]
then
 simul="_$2"
else
 simul=""
fi
suffix=${exec}${simul}
#
## save suffixe-free output files
rm -f *.nc.zzzztemporary
if [ -f histmth.nc ]
then
mv histmth.nc histmth.nc.zzzztemporary
fi
if [ -f histday.nc ]
then
mv histday.nc histday.nc.zzzztemporary
fi
if [ -f histhf.nc ]
then
mv histhf.nc  histhf.nc.zzzztemporary
fi
if [ -f histins.nc ]
then
mv histins.nc histins.nc.zzzztemporary
fi
if [ -f histLES.nc ]
then
mv histLES.nc histLES.nc.zzzztemporary
fi
##
./lmdz1d${exec}.e > lmdz1d${exec}.lis
tail -2 lmdz1d${exec}.lis
#
if [ -f histmth.nc ]
then
  time_name=`ncdump -h histmth.nc|grep 't_inst_.*(time_counter)'|sed -e"s/^.*t_inst_\(.*\)(time_counter).*$/t_inst_\1/"`
  ncrename -v ${time_name},time_counter histmth.nc
  ncatted -O -a positive,presnivs,o,c,down -a _FillValue,,m,f,1.e35 histmth.nc 
  if [ -n "${suffix}" ]
  then
   cp -f histmth.nc histmth${suffix}.nc
   rm -f histmth.nc
   mv histmth.nc.zzzztemporary histmth.nc
  else
   rm -f histmth.nc.zzzztemporary
  fi
elif [ -f histmth.nc.zzzztemporary ]
then
  mv histmth.nc.zzzztemporary histmth.nc
fi
if [ -f histday.nc ]
then
  time_name=`ncdump -h histday.nc|grep 't_inst_.*(time_counter)'|sed -e"s/^.*t_inst_\(.*\)(time_counter).*$/t_inst_\1/"`
  ncrename -v ${time_name},time_counter histday.nc
  ncatted -O -a positive,presnivs,o,c,down -a _FillValue,,m,f,1.e35 histday.nc 
  if [ -n "${suffix}" ]
  then
   cp -f histday.nc histday${suffix}.nc
   rm -f histday.nc
   mv histday.nc.zzzztemporary histday.nc
  else
   rm -f histday.nc.zzzztemporary
  fi
elif [ -f histday.nc.zzzztemporary ]
then
  mv histday.nc.zzzztemporary histday.nc
fi
if [ -f histhf.nc ]
then
  time_name=`ncdump -h histhf.nc|grep 't_inst_.*(time_counter)'|sed -e"s/^.*t_inst_\(.*\)(time_counter).*$/t_inst_\1/"`
  ncrename -v ${time_name},time_counter histhf.nc
  ncatted -O -a positive,presnivs,o,c,down -a _FillValue,,m,f,1.e35 histhf.nc 
  if [ -n "${suffix}" ]
  then
   cp -f histhf.nc histhf${suffix}.nc
   rm -f histhf.nc
   mv histhf.nc.zzzztemporary histhf.nc
  else
   rm -f histhf.nc.zzzztemporary
  fi
elif [ -f histhf.nc.zzzztemporary ]
then
  mv histhf.nc.zzzztemporary histhf.nc
fi
if [ -f histins.nc ]
then
  time_name=`ncdump -h histins.nc|grep 't_inst_.*(time_counter)'|sed -e"s/^.*t_inst_\(.*\)(time_counter).*$/t_inst_\1/"`
  ncrename -v ${time_name},time_counter histins.nc
  ncatted -O -a positive,presnivs,o,c,down -a _FillValue,,m,f,1.e35 histins.nc 
  if [ -n "${suffix}" ]
  then
   cp -f histins.nc histins${suffix}.nc
   rm -f histins.nc
   mv histins.nc.zzzztemporary histins.nc
  else
   rm -f histins.nc.zzzztemporary
  fi
elif [ -f histins.nc.zzzztemporary ]
then
  mv histins.nc.zzzztemporary histins.nc
fi
if [ -f histLES.nc ]
then
  time_name=`ncdump -h histLES.nc|grep 't_inst_.*(time_counter)'|sed -e"s/^.*t_inst_\(.*\)(time_counter).*$/t_inst_\1/"`
  ncrename -v ${time_name},time_counter histLES.nc
  ncatted -O -a positive,presnivs,o,c,down -a _FillValue,,m,f,1.e35 histLES.nc 
  if [ -n "${suffix}" ]
  then
   cp -f histLES.nc histLES${suffix}.nc
   rm -f histLES.nc
   mv histLES.nc.zzzztemporary histLES.nc
  else
   rm -f histLES.nc.zzzztemporary
  fi
elif [ -f histLES.nc.zzzztemporary ]
then
  mv histLES.nc.zzzztemporary histLES.nc
fi

